@@ -29,8 +29,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import ApplicationComponentCriteriaType, ServerCriteriaType, SortOrderType
 from .type_defs import (
@@ -62,7 +61,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class GetServerDetailsPaginator(Boto3Paginator):
+class GetServerDetailsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.GetServerDetails)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/paginators/#getserverdetailspaginator)
@@ -77,7 +76,7 @@ class GetServerDetailsPaginator(Boto3Paginator):
         """
 
 
-class ListApplicationComponentsPaginator(Boto3Paginator):
+class ListApplicationComponentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListApplicationComponents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/paginators/#listapplicationcomponentspaginator)
@@ -98,7 +97,7 @@ class ListApplicationComponentsPaginator(Boto3Paginator):
         """
 
 
-class ListCollectorsPaginator(Boto3Paginator):
+class ListCollectorsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListCollectors)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/paginators/#listcollectorspaginator)
@@ -113,7 +112,7 @@ class ListCollectorsPaginator(Boto3Paginator):
         """
 
 
-class ListImportFileTaskPaginator(Boto3Paginator):
+class ListImportFileTaskPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListImportFileTask)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/paginators/#listimportfiletaskpaginator)
@@ -128,7 +127,7 @@ class ListImportFileTaskPaginator(Boto3Paginator):
         """
 
 
-class ListServersPaginator(Boto3Paginator):
+class ListServersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Paginator.ListServers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/paginators/#listserverspaginator)
